#
# This rpm is based on the git tree from:
# git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# version is date of the youngest commit
#
# it's advisable to get a full tagged release rather than a versioned of a singled commit.
#
# e.g.
# tagged_firmware=20240909
# wget https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/snapshot/linux-firmware-${tagged_firmware}.tar.gz

Summary:	Open source Linux kernel firmware files
Name:   	kernel-firmware
Version:	20250109
Release:	%mkrel 1
License:	GPLv2 and GPLv2+ and GPLv3
Group:  	System/Kernel and hardware
URL:    	https://www.kernel.org/
#
# The linux-firmware tarball is generated from the git tree mentioned
# above, by simply cloning it, and  doing:
#
#   git archive --prefix=linux-firmware/ origin/main | xz > linux-firmware-20240909.tar.xz
#
# or by using wget with the tagged version as adviced above.
#
# Then use gen-free-firmware-tarball.sh to generate a free-only and a nonfree tarball
# to be used in kernel-firmware-nonfree from the full firmware tarball. E.g.:
#
#    ./gen-free-firmware-tarball.sh linux-firmware-20240909.tar.gz 20240909
#
# which will produce:
#
# linux-firmware-free-20240909.tar.xz and linux-firmware-nonfree-20240909.tar.xz
#
Source0: 	linux-firmware-free-%{version}.tar.xz
Source1:	gen-free-firmware-tarball.sh
%rename		carl9170-firmware
Conflicts:	kernel-firmware-extra < %{version}-1
Conflicts:	kernel-firmware-nonfree < %{version}-1
Conflicts:	radeon-firmware < 20130624-1
Recommends:	kernel-firmware-nonfree
BuildArch:	noarch

%description
This package contains all the open source firmware for in-kernel drivers.

This package includes the firmware for keyspan_pda, dsp56k, pcnet_cs,
3c589_cs, 3c574_cs, serial_cs, dvb-ttpci (base), isci, usbdux.

Other firmware is contained in the radeon-firmware, iwlwifi-*-ucode,
rtlwifi-firmware, and kernel-firmware-nonfree packages in the nonfree section.

%prep
%setup -q -n linux-firmware-free-%{version}

# .bin files are only Redistributable, GPLv2 files are just .txt files
rm -rf brcm cypress

%install
mkdir -p %{buildroot}/lib/firmware
cp -avf * %{buildroot}/lib/firmware
rm -f %{buildroot}/lib/firmware/{WHENCE,GPL*}

%files
%defattr(0644,root,root,0755)
%doc WHENCE
# Check license before adding/removing files here,
# the tarball script is not fault-proof.
%dir /lib/firmware/atusb
/lib/firmware/atusb/atusb-0.2.dfu
/lib/firmware/atusb/atusb-0.3.dfu
/lib/firmware/atusb/rzusb-0.3.bin
%dir /lib/firmware/av7110
/lib/firmware/av7110/bootcode.bin
%dir /lib/firmware/cis
/lib/firmware/cis/*.cis
%dir /lib/firmware/dsp56k
/lib/firmware/dsp56k/bootstrap.bin
%dir /lib/firmware/isci
/lib/firmware/isci/isci_firmware.bin
%dir /lib/firmware/keyspan_pda
/lib/firmware/keyspan_pda/*.fw
/lib/firmware/usbdux*_firmware.bin
%dir /lib/firmware/r128
/lib/firmware/r128/r128_cce.bin
%dir /lib/firmware/radeon
/lib/firmware/radeon/R100_cp.bin
/lib/firmware/radeon/R200_cp.bin
/lib/firmware/radeon/R300_cp.bin
/lib/firmware/radeon/R420_cp.bin
/lib/firmware/radeon/R520_cp.bin
/lib/firmware/radeon/R600_me.bin
/lib/firmware/radeon/R600_pfp.bin
/lib/firmware/radeon/RS600_cp.bin
/lib/firmware/radeon/RS690_cp.bin
/lib/firmware/radeon/RS780_me.bin
/lib/firmware/radeon/RS780_pfp.bin
/lib/firmware/radeon/RV610_me.bin
/lib/firmware/radeon/RV610_pfp.bin
/lib/firmware/radeon/RV620_me.bin
/lib/firmware/radeon/RV620_pfp.bin
/lib/firmware/radeon/RV630_me.bin
/lib/firmware/radeon/RV630_pfp.bin
/lib/firmware/radeon/RV635_me.bin
/lib/firmware/radeon/RV635_pfp.bin
/lib/firmware/radeon/RV670_me.bin
/lib/firmware/radeon/RV670_pfp.bin
/lib/firmware/radeon/RV710_me.bin
/lib/firmware/radeon/RV710_pfp.bin
/lib/firmware/radeon/RV730_me.bin
/lib/firmware/radeon/RV730_pfp.bin
/lib/firmware/radeon/RV770_me.bin
/lib/firmware/radeon/RV770_pfp.bin
/lib/firmware/carl9170-1.fw


%changelog
* Sun Jan 26 2025 wally <wally> 20250109-1.mga10
+ Revision: 2142624
- new version 20250109

* Wed Oct 23 2024 ghibo <ghibo> 20240909-1.mga10
+ Revision: 2110352
- Update to version 2024-09-09.
- Add a fix to gen-free-firmware-tarball.sh.

* Sat Nov 11 2023 ghibo <ghibo> 20231111-1.mga10
+ Revision: 2006120
- Update to snapshot 20231111

* Sat Jul 01 2023 tmb <tmb> 20230625-1.mga9
+ Revision: 1963418
- update to 20230625 snapshot

* Mon May 15 2023 tmb <tmb> 20230515-1.mga9
+ Revision: 1957021
- update to 20230515

* Fri Feb 10 2023 tmb <tmb> 20230210-1.mga9
+ Revision: 1940045
- update to 20230210

* Sat Jan 14 2023 tmb <tmb> 20230110-1.mga9
+ Revision: 1932971
- update to 20230110

* Fri Sep 16 2022 tmb <tmb> 20220913-1.mga9
+ Revision: 1889198
- update to 20220913 snapshot

* Mon Mar 21 2022 umeabot <umeabot> 20220101-2.mga9
+ Revision: 1815869
- Mageia 9 Mass Rebuild

* Sat Jan 01 2022 tmb <tmb> 20220101-1.mga9
+ Revision: 1765800
- update to 20220101 snapshot

* Sun Dec 20 2020 tmb <tmb> 20201218-1.mga8
+ Revision: 1661446
- update to 20201218 snapshot

* Thu Aug 06 2020 luigiwalser <luigiwalser> 20200721-1.mga8
+ Revision: 1611537
- update to 20200721 snapshot (files should be the same as 20190603)
- fix gen-free-firmware-tarball.sh script (mostly)
- account for one remaining issue in script in SPEC file

* Sat Feb 15 2020 umeabot <umeabot> 20190603-2.mga8
+ Revision: 1526653
- Mageia 8 Mass Rebuild

* Sat Jun 15 2019 tmb <tmb> 20190603-1.mga7
+ Revision: 1399972
- update to 2019-06-03 snapshot

* Mon Apr 22 2019 tmb <tmb> 20190422-1.mga7
+ Revision: 1394797
- update to 20190422 snapshot

* Mon Jan 14 2019 tmb <tmb> 20190114-1.mga7
+ Revision: 1356861
- update to 2019-01-14 snapshot

* Wed Nov 28 2018 tmb <tmb> 20181026-1.mga7
+ Revision: 1336558
- update to 2018-10-26 snapshot

* Thu Sep 20 2018 umeabot <umeabot> 20180606-2.mga7
+ Revision: 1279181
- Mageia 7 Mass Rebuild

* Sun Jul 08 2018 tmb <tmb> 20180606-1.mga7
+ Revision: 1242676
- update to 2018-06-06 snapshot

* Sat Feb 17 2018 tmb <tmb> 20180211-1.mga7
+ Revision: 1202149
- update to 2018-02-11 snapshot
- update to 2018-02-11 snapshot

* Mon Jun 05 2017 tmb <tmb> 20170531-1.mga6
+ Revision: 1106767
- update to 2017-05-31 snapshot

* Tue Feb 21 2017 tmb <tmb> 20170217-1.mga6
+ Revision: 1087228
- update to 2017-02-17 snapshot

* Sun Jan 15 2017 tmb <tmb> 20170113-1.mga6
+ Revision: 1081810
- update to 20170113 snapshot

* Sun Jan 01 2017 tmb <tmb> 20170101-1.mga6
+ Revision: 1079383
- update filelist
- update to 20170101 snapshot

* Tue Sep 20 2016 tmb <tmb> 20160914-1.mga6
+ Revision: 1054760
- usbdux: usbduxsigma: created matching binary of the firmware

* Wed Jul 20 2016 tmb <tmb> 20160712-1.mga6
+ Revision: 1042792
- update to 2016-07-12 snapshot

* Sun Jun 19 2016 tmb <tmb> 20160608-1.mga6
+ Revision: 1036776
- update to 20160608 snapshot

* Sat Apr 09 2016 tmb <tmb> 20160409-1.mga6
+ Revision: 999885
- update ot 20160409 snapshot

* Thu Mar 03 2016 tmb <tmb> 20160219-1.mga6
+ Revision: 984597
- update to 2016-02-19 snapshot
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Nov 21 2015 tmb <tmb> 20151120-1.mga6
+ Revision: 904757
- update to 2015-11-20

* Tue Aug 04 2015 tmb <tmb> 20150722-1.mga6
+ Revision: 861096
- update to 2015-07-22
  * add firmware for atusb driver

* Tue Mar 10 2015 tmb <tmb> 20150309-1.mga5
+ Revision: 818298
- update to 2015-03-09

* Wed Feb 04 2015 tmb <tmb> 20150204-1.mga5
+ Revision: 813486
- update to 2015-02-04

* Mon Dec 01 2014 tmb <tmb> 20141106-1.mga5
+ Revision: 800164
- update to 20141106

* Wed Oct 15 2014 umeabot <umeabot> 20140603-3.mga5
+ Revision: 750163
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20140603-2.mga5
+ Revision: 681037
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Jun 04 2014 tmb <tmb> 20140603-1.mga5
+ Revision: 632974
- update to 2014-06-03

* Tue Oct 22 2013 umeabot <umeabot> 20131013-2.mga4
+ Revision: 542310
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 tmb <tmb> 20131013-1.mga4
+ Revision: 497330
- update to 2013-10-13

* Tue Jul 09 2013 tmb <tmb> 20130624-1.mga4
+ Revision: 452126
- update to 2013-06-24 snapshot
- re-add proper list of free radeon drivers
- ship all radeon firmwares in radeon-firmware

* Mon Apr 08 2013 tmb <tmb> 20130307-2.mga3
+ Revision: 409065
- provide carl9170-firmware for upgrades to work

* Sun Apr 07 2013 tmb <tmb> 20130307-1.mga3
+ Revision: 409015
- fix filelist
- obsolete carl9170-firmware (merged upstream)
- update to 203-03-07

* Thu Jan 10 2013 tmb <tmb> 20121225-1.mga3
+ Revision: 344671
- update to 2012-12-25

* Fri Nov 02 2012 tmb <tmb> 20121030-1.mga3
+ Revision: 312669
- update to 2012-10-30 snapshot

* Sun Sep 16 2012 tmb <tmb> 20120909-1.mga3
+ Revision: 294476
- update to 2012-09-09 snapshot

* Sat Jul 21 2012 tmb <tmb> 20120719-2.mga3
+ Revision: 273008
- fix conflicts on radeon-firmware

* Fri Jul 20 2012 tmb <tmb> 20120719-1.mga3
+ Revision: 272967
- update to 2012-07-19 snapshot

* Tue Mar 06 2012 tmb <tmb> 20120219-1.mga2
+ Revision: 220088
- update to 2012-02-19 snapshot

* Sun Jan 01 2012 tmb <tmb> 20111229-1.mga2
+ Revision: 189462
- conflict old kernel-firmware-extra
- update to 2011-12-29 snapshot
- update filelists
- create nonfree only tarball at the same time as we create the
  free tarball to avoid useless duplication in srpms, and to
  simplify the creation of kernel-firmware-nonfree
- fix git url
- drop buildroot

* Tue Nov 08 2011 anssi <anssi> 20110703-2.mga2
+ Revision: 165566
- drop non-free firmware (they will be included in the
  kernel-firmware-extra and radeon-firmware packages in the nonfree
  section)
- add free usbdux firmware (moved from kernel-firmware-extra)
- drop non-free obsoletes (to be put in kernel-firmware-extra)
- add gen-free-firmware-tarball.sh to help packaging
- update summary and description
- fix license tag
- drop pcmcia firmware source code from the binary package
+ tmb <tmb>
- update to 2011-07-03 checkout
  * updates bnx2x fw to 6.2.9
  * adds isci: Intel(R) C600 Series Chipset Storage Controller fw

* Thu Mar 17 2011 tmb <tmb> 20110314-2.mga1
+ Revision: 73536
- fix conflicts on kernel-firmware-extra

* Thu Mar 17 2011 tmb <tmb> 20110314-1.mga1
+ Revision: 73359
- update to 2011-03-14

* Tue Jan 25 2011 tmb <tmb> 20101231-1.mga1
+ Revision: 39043
- update to 2010-12-31 snapshot

* Sat Jan 08 2011 tmb <tmb> 20101024-2.mga1
+ Revision: 1228
- imported package kernel-firmware


* Sat Jan 08 2011 Thomas Backlund <tmb@mageia.org> 20101024-2.mga1
- initial Mageia import
- drop rpm tags
- switch from manbo_mkrel to mkrel

* Thu Nov 04 2010 Thomas Backlund <tmb@mandriva.org> 20101024-1mnb2
+ Revision: 593285
- update to 2010-10-24

* Sun Aug 15 2010 Thomas Backlund <tmb@mandriva.org> 20100804-1mnb2
+ Revision: 570139
- update to 2010-08-04

* Mon May 03 2010 Thomas Backlund <tmb@mandriva.org> 20100217-1mnb2
+ Revision: 541831
- keep bnx2x fw for 2.6.33 series kernels
- update to 20100217 (updated bnx2 and bnx2x firmwares)

* Sun Feb 07 2010 Thomas Backlund <tmb@mandriva.org> 20100107-1mnb2
+ Revision: 501683
- drop firmware tarball from drm-next as its merged upstream
- update to 2010-01-07

* Sat Sep 19 2009 Thomas Backlund <tmb@mandriva.org> 20090604-4mnb2
+ Revision: 444767
- update drm-next firmware to 2009-09-18

* Thu Sep 17 2009 Thomas Backlund <tmb@mandriva.org> 20090604-3mnb2
+ Revision: 444038
- use correct radeon ihex-converted firmware tarball

* Thu Sep 17 2009 Thomas Backlund <tmb@mandriva.org> 20090604-2mnb2
+ Revision: 443983
- add radeon firmware from drm-next, needed by kernel-tmb
- update to 2009-06-04

* Thu May 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090418-1mnb2
+ Revision: 380647
- Updated to 20090418
- Use lzma for source tarball.

* Mon Mar 30 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090111-3mnb2
+ Revision: 362326
- Re-add obsoletes from kernel-firmware-extra to kernel-firmware for
  firmware files which moved to kernel-firmware after previous change.

* Mon Mar 30 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090111-2mnb2
+ Revision: 362309
- Include all firmware, not splitting firmwares into
  kernel-firmware-extra (#49195).

* Tue Feb 17 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090111-1mnb2
+ Revision: 341862
- Updated to 20090111

* Fri Dec 05 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20080922-2mnb2
+ Revision: 310782
- Don't include firmware without source, they should be in non-free
  (distributed with kernel-firmware-extra package).
- Suggests kernel-firmware-extra.
- Cosmetics.

* Tue Nov 04 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20080922-1mnb2
+ Revision: 299838
- Updated to latest linux-firmware-from-kernel snapshot, and change
  versioning to use date of the younger commit, as firmwares aren't
  bound to specific kernel version.

* Sat Sep 06 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-2mnb2
+ Revision: 281995
- Obsolete korg1212-firmware, maestro3-firmware, sb16-firmware, yamaha-firmware.

* Thu Aug 28 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-1mnb2
+ Revision: 277014
- redo spec based on kernel-headers spec
- switch to using dwmw2's linux-firmware-from-kernel git tree
- no need to follow -rc/-git versioning as the firmwares does
  not change that often.
- package is now noarch as we dont build anything
- switch to Manbo Core tagging

* Thu Aug 21 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-0.rc4.1mdv2009.0
+ Revision: 274527
- update to 2.6.27-rc4

* Wed Aug 20 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-0.rc3.1mdv2009.0
+ Revision: 274212
- fix git typo
- update to 2.6.27-rc3-git6

* Thu Aug 07 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-0.rc2.2mdv2009.0
+ Revision: 265550
- bump release
- add buildrequires

* Thu Aug 07 2008 Thomas Backlund <tmb@mandriva.org> 2.6.27-0.rc2.1mdv2009.0
+ Revision: 265537
- add spec file
- use defconfigs from kernel-linus
- start with 2.6.27-rc2
- Created package structure for kernel-firmware.

